@@ -19,8 +19,8 @@ my $config   = file( $FindBin::RealBin, 'config.yaml' )->stringify;
 Getopt::Long::GetOptions(
     '--para=i'       => \$fork_num,
     '--dry-run'      => \my $dry_run_fg,
-    '--skip=s'       => \my $skips,
-    '--with=s'       => \my $withs,
+    '--skip=s'       => \my @skips,
+    '--with=s'       => \my @withs,
     '--only=s'       => \my $only,
     '--shell',       => \my $shell,
     '--man'          => \my $man,
@@ -44,8 +44,8 @@ if ( !@ARGV ) {
             {   project      => $project,
                 dry_run_fg   => $dry_run_fg,
                 parallel_num => $fork_num,
-                skips => +{ map { $_ => 1 } split /,/, ( $skips || '' ) },
-                withs => +{ map { $_ => 1 } split /,/, ( $withs || '' ) },
+                skips => +{ map { $_ => 1 } map {split /,/, $_} @skips },
+                withs => +{ map { $_ => 1 } map {split /,/, $_} @withs },
                 only        => $only,
                 log_level   => $log_level,
                 config_yaml => $config,
@@ -75,8 +75,8 @@ for my $proj ( @ARGV ) {
         {   project      => $proj,
             dry_run_fg   => $dry_run_fg,
             parallel_num => $fork_num,
-            skips        => +{ map { $_ => 1 } split /,/, ( $skips || '' ) },
-            withs        => +{ map { $_ => 1 } split /,/, ( $withs || '' ) },
+            skips        => +{ map { $_ => 1 } map {split /,/, $_} @skips },
+            withs        => +{ map { $_ => 1 } map {split /,/, $_} @withs },
             only         => $only,
             log_level    => $log_level,
             config_yaml  => $config,
@@ -109,11 +109,6 @@ __END__
 
 Automating Application Deployment.
 
-=head1 TODO
-
-    logging.
-    para=half.
-
 =head1 TIPS
 
 add to .zshrc.
@@ -122,4 +117,4 @@ add to .zshrc.
 
 =head1 AUTHORS
 
-Tokuhiro Matsuno <tokuhiro at mobilefactory.jp>.
+Tokuhiro Matsuno
